summaryrefslogtreecommitdiffstats
path: root/openpgp-ffi/src
diff options
context:
space:
mode:
authorJustus Winter <justus@sequoia-pgp.org>2019-12-03 17:38:49 +0100
committerJustus Winter <justus@sequoia-pgp.org>2019-12-04 13:20:26 +0100
commit807eee2432de52715a2e3c7167d5e859ca3315a8 (patch)
treeca712d38feec4caa46c0105f1f0f9d45400c7d55 /openpgp-ffi/src
parentdaee0e230c36cec119d523ca33407789b6fd109f (diff)
openpgp: Rename KeyIter filters.
- See #359.
Diffstat (limited to 'openpgp-ffi/src')
-rw-r--r--openpgp-ffi/src/cert.rs24
1 files changed, 12 insertions, 12 deletions
diff --git a/openpgp-ffi/src/cert.rs b/openpgp-ffi/src/cert.rs
index 5385a61d..6b223a3a 100644
--- a/openpgp-ffi/src/cert.rs
+++ b/openpgp-ffi/src/cert.rs
@@ -498,14 +498,14 @@ pub extern "C" fn pgp_cert_key_iter_free(
/// Changes the iterator to only return keys that are certification
/// capable.
///
/// If you call this function and, e.g., the `signing_capable`
/// function, the *union* of the values is used. That is, the
/// iterator will return keys that are certification capable *or*
/// signing capable.
///
/// Note: you may not call this function after starting to iterate.
#[::sequoia_ffi_macros::extern_fn] #[no_mangle]
-pub extern "C" fn pgp_cert_key_iter_certification_capable<'a>(
+pub extern "C" fn pgp_cert_key_iter_for_certification<'a>(
iter_wrapper: *mut KeyIterWrapper<'a>)
{
let iter_wrapper = ffi_param_ref_mut!(iter_wrapper);
@@ -515,20 +515,20 @@ pub extern "C" fn pgp_cert_key_iter_certification_capable<'a>(
use std::mem;
let tmp = mem::replace(&mut iter_wrapper.iter, KeyIter::empty());
- iter_wrapper.iter = tmp.certification_capable();
+ iter_wrapper.iter = tmp.for_certification();
}
/// Changes the iterator to only return keys that are certification
/// capable.
///
/// If you call this function and, e.g., the `signing_capable`
/// function, the *union* of the values is used. That is, the
/// iterator will return keys that are certification capable *or*
/// signing capable.
///
/// Note: you may not call this function after starting to iterate.
#[::sequoia_ffi_macros::extern_fn] #[no_mangle]
-pub extern "C" fn pgp_cert_key_iter_signing_capable<'a>(
+pub extern "C" fn pgp_cert_key_iter_for_signing<'a>(
iter_wrapper: *mut KeyIterWrapper<'a>)
{
let iter_wrapper = ffi_param_ref_mut!(iter_wrapper);
@@ -538,20 +538,20 @@ pub extern "C" fn pgp_cert_key_iter_signing_capable<'a>(
use std::mem;
let tmp = mem::replace(&mut iter_wrapper.iter, KeyIter::empty());
- iter_wrapper.iter = tmp.signing_capable();
+ iter_wrapper.iter = tmp.for_signing();
}
/// Changes the iterator to only return keys that are capable of
/// encrypting data at rest.
///
/// If you call this function and, e.g., the `signing_capable`
/// function, the *union* of the values is used. That is, the
/// iterator will return keys that are certification capable *or*
/// signing capable.
///
/// Note: you may not call this function after starting to iterate.
#[::sequoia_ffi_macros::extern_fn] #[no_mangle]
-pub extern "C" fn pgp_cert_key_iter_encrypting_capable_at_rest<'a>(
+pub extern "C" fn pgp_cert_key_iter_for_storage_encryption<'a>(
iter_wrapper: *mut KeyIterWrapper<'a>)
{
let iter_wrapper = ffi_param_ref_mut!(iter_wrapper);
@@ -560,20 +560,20 @@ pub extern "C" fn pgp_cert_key_iter_encrypting_capable_at_rest<'a>(
}
let tmp = std::mem::replace(&mut iter_wrapper.iter, KeyIter::empty());
- iter_wrapper.iter = tmp.encrypting_capable_at_rest();
+ iter_wrapper.iter = tmp.for_storage_encryption();
}
/// Changes the iterator to only return keys that are capable of
/// encrypting data for transport.
///
/// If you call this function and, e.g., the `signing_capable`
/// function, the *union* of the values is used. That is, the
/// iterator will return keys that are certification capable *or*
/// signing capable.
///
/// Note: you may not call this function after starting to iterate.
#[::sequoia_ffi_macros::extern_fn] #[no_mangle]
-pub extern "C" fn pgp_cert_key_iter_encrypting_capable_for_transport<'a>(
+pub extern "C" fn pgp_cert_key_iter_for_transport_encryption<'a>(
iter_wrapper: *mut KeyIterWrapper<'a>)
{
let iter_wrapper = ffi_param_ref_mut!(iter_wrapper);
@@ -582,7 +582,7 @@ pub extern "C" fn pgp_cert_key_iter_encrypting_capable_for_transport<'a>(
}
let tmp = std::mem::replace(&mut iter_wrapper.iter, KeyIter::empty());
- iter_wrapper.iter = tmp.encrypting_capable_for_transport();
+ iter_wrapper.iter = tmp.for_transport_encryption();
}
/// Changes the iterator to only return keys that are alive.
@@ -498,14 +498,14 @@ pub extern "C" fn pgp_cert_key_iter_free(
/// capable.
///
-/// If you call this function and, e.g., the `signing_capable`
+/// If you call this function and, e.g., the `for_signing`
/// function, the *union* of the values is used. That is, the
/// iterator will return keys that are certification capable *or*
@@ -515,20 +515,20 @@ pub extern "C" fn pgp_cert_key_iter_certification_capable<'a>(
/// capable.
///
-/// If you call this function and, e.g., the `signing_capable`
+/// If you call this function and, e.g., the `for_signing`
/// function, the *union* of the values is used. That is, the
/// iterator will return keys that are certification capable *or*
@@ -538,20 +538,20 @@ pub extern "C" fn pgp_cert_key_iter_signing_capable<'a>(
/// encrypting data at rest.
///
-/// If you call this function and, e.g., the `signing_capable`
+/// If you call this function and, e.g., the `for_signing`
/// function, the *union* of the values is used. That is, the
/// iterator will return keys that are certification capable *or*
@@ -560,20 +560,20 @@ pub extern "C" fn pgp_cert_key_iter_encrypting_capable_at_rest<'a>(
/// encrypting data for transport.
///
-/// If you call this function and, e.g., the `signing_capable`
+/// If you call this function and, e.g., the `for_signing`
/// function, the *union* of the values is used. That is, the
/// iterator will return keys that are certification capable *or*